@@ -464,7 +464,7 @@ _Config = [
     dict(path='/config/shaken/ani_pool_group/list', method='get',resource=shaken.ShakenAniGroupListRelList() ),
     dict(path='/config/stir_shaken_config/create', method='post',resource=shaken.ShakenStiSpConfCreate() ),
     # dict(path='/config/stir_shaken_config', method='get',resource=shaken.ShakenStiSpConfList() ),
-    dict(path='/config/stir_shaken_config', method='post',resource=shaken.ShakenStiSpConfResource() ),
+    dict(path='/config/stir_shaken_config/{id}', method='post',resource=shaken.ShakenStiSpConfResource() ),
 
 
     dict(path='/config/us_jurisdictionprefix/create', resource=view.JurisdictionPrefixCreate(), method='post'),
