@@ -18,7 +18,7 @@ from api_dnl import settings
 from api_dnl.resources import check_context, DnlResource,DnlList, ValidationError, DnlCreate, CustomGetAction, CustomPostAction, \
     CustomDeleteAction
 from api_dnl.schemes.shaken import *
-from api_dnl.scheme import SendCdrDirectScheme, ObjectCreatedMultipleScheme, ShakenStiSpConfScheme
+from api_dnl.scheme import SendCdrDirectScheme, ObjectCreatedMultipleScheme, ShakenStiSpConfScheme, ShakenStiSpConfSchemeModify
 from api_dnl.view import DEFAULT_SECURITY, OperationErrorResponse
 import json
 from api_dnl.views.report import Report
@@ -362,11 +362,6 @@ class ShakenStiSpConfCreate(DnlCreate):
     security = (DEFAULT_SECURITY)
     restrict = ()
 
-    # priv_key = String()
-    # passphrase = String()
-    # x5u = String()
-    # id = Bool()
-    # enabled = Bool()
     def get_spec(self):
         additional_responses = (
                                    responses.OperationErrorResponse(data=errors.CommonErrors.PermissionError,
@@ -374,12 +369,10 @@ class ShakenStiSpConfCreate(DnlCreate):
                                ) + self.additional_responses
 
         ext_body_parameters = (
-            {'name': 'priv_file', 'in': 'formData', 'description': 'File to upload', 'required': True, 'type': 'file'},
-            {'name': 'passphrase', 'in': 'formData', 'description': 'Specified group', 'required': False,
-             'type': 'string'},
+            {'name': 'priv_key', 'in': 'formData', 'required': True, 'type': 'string'},
+            {'name': 'passphrase', 'in': 'formData', 'required': False, 'type': 'string'},
             {'name': 'x5u', 'in': 'formData', "type": "string", 'required': False},
-            {'name': 'id', 'in': 'formData', "type": "boolean"},
-            {'name': 'enabled', 'in': 'formData', "type": "boolean"},
+            {'name': 'default_key', 'in': 'formData', "type": "boolean"},
         )
         return swagger.specify.get_spec(
             method='post', description='Creates new {}'.format(self.entity.lower()),
@@ -396,98 +389,122 @@ class ShakenStiSpConfCreate(DnlCreate):
             ext_body_parameters=ext_body_parameters
         )
 
-
     def on_post(self, req, resp, **kwargs):
+        default_key = req.data.get("default_key") == "true"
+        session = model.get_db().session
         try:
-            file_data = req.files['priv_file'].read()
-            req.data['priv_key'] = file_data.decode('utf-8')
+            if default_key:
+                sql = text("""
+                    WITH reset AS (
+                        UPDATE public.shaken_sti_sp_conf
+                        SET default_key = NULL
+                        WHERE default_key = TRUE
+                    )
+                    INSERT INTO public.shaken_sti_sp_conf (priv_key, passphrase, x5u, default_key)
+                    VALUES (:priv_key, :passphrase, :x5u, TRUE)
+                    RETURNING id;
+                """)
+                result = session.execute(sql, {
+                    "priv_key": req.data.get("priv_key"),
+                    "passphrase": req.data.get("passphrase"),
+                    "x5u": req.data.get("x5u"),
+                })
+                new_id = result.scalar()
+
+            else:
+                sql = text("""
+                    INSERT INTO public.shaken_sti_sp_conf (priv_key, passphrase, x5u, default_key)
+                    VALUES (:priv_key, :passphrase, :x5u, NULL)
+                    RETURNING id;
+                """)
+                result = session.execute(sql, {
+                    "priv_key": req.data.get("priv_key"),
+                    "passphrase": req.data.get("passphrase"),
+                    "x5u": req.data.get("x5u"),
+                })
+                new_id = result.scalar()
+
+            session.commit()
+            self.set_response(resp, responses.SuccessResponse(
+                data={
+                    'object_id': new_id,
+                },
+                scheme=schemes.ObjectScheme
+            ))
+            return True
+
         except Exception as e:
-            log.debug(f"ShakenStiSpConfCreate error {e}")
-            raise falcon.HTTPBadRequest('Invalid file', 'File upload failed.')
+            session.rollback()
+            log.error('Error during processing: {}'.format(str(e)))
+            self.set_response(resp, OperationErrorResponse(e))
+            return False
 
-        return super().on_post(req, resp, **kwargs)
-
-
-    def before_create(self, obj, **kwargs):
-        model.ShakenStiSpConf.filter().delete(synchronize_session='fetch')
-        return super().before_create(obj, **kwargs)
 
 class ShakenStiSpConfResource(DnlResource):
     model_class = model.ShakenStiSpConf
     scheme_class = ShakenStiSpConfScheme
     scheme_class_get = ShakenStiSpConfScheme
-    scheme_class_modify = ShakenStiSpConfScheme
+    scheme_class_modify = ShakenStiSpConfSchemeModify
     entity = 'ShakenStiSpConf'
+    id_field = 'id'
     security = (DEFAULT_SECURITY)
     restrict = ()
-    # has_modify_operation = False
-
-    def on_get(self, req, resp, **kwargs):
-        try:
-            objects_list, count = self.model_class.get_objects_list()
-            if count and count == 1:
-                priv_key = objects_list[0].priv_key.strip().split('\n')[1]
-                response_data = {
-                    "priv_key": priv_key,
-                    "passphrase": objects_list[0].passphrase,
-                    "x5u": objects_list[0].x5u,
-                    "enabled": objects_list[0].enabled,
-                }
-                resp.status = falcon.HTTP_200
-                resp.media = response_data
-            else:
-                self.set_response(resp, responses.ObjectNotFoundErrorResponse(data='config  not found'))
-                return False
-
-        except Exception as e:
-            log.debug(f"ShakenStiSpConfGet error {e}")
-            self.set_response(resp, responses.OperationErrorResponse(data=str(e)))
-
-    def on_delete(self, req, resp, **kwargs):
-        try:
-            objects_list, count = self.model_class.get_objects_list()
-            if count == 1:
-                self.model_class.filter().delete(synchronize_session='fetch')
-                resp.status = falcon.HTTP_200
-                resp.body = json.dumps({'success': True})
-            else:
-                self.set_response(resp, responses.ObjectNotFoundErrorResponse(data='config not found'))
-                return False
-        except Exception as e:
-            log.error(f"Error during deletion: {e}")
-            self.set_response(resp, responses.OperationErrorResponse(data=str(e)))
 
 
     def on_patch(self, req, resp, **kwargs):
+        session = model.get_db().session
+        default_key = req.data.get('default_key')
+        object_id = kwargs['id']
+        
         try:
-            priv_key = None
-            updates = {}
-
-            if 'priv_key' in req.data:
-                updates['priv_key'] = req.data['priv_key'].strip()
-
-            if 'passphrase' in req.data:
-                updates['passphrase'] = req.data['passphrase']
-            if 'x5u' in req.data:
-                updates['x5u'] = req.data['x5u']
-            if 'enabled' in req.data:
-                updates['enabled'] = req.data['enabled']
-
-            objects_list, count = self.model_class.get_objects_list()
-            if count == 1:
-                conf = objects_list[0]
-                for key, value in updates.items():
-                    setattr(conf, key, value)
-                conf.save()
-                resp.status = falcon.HTTP_200
-                resp.media = conf.as_dict()
+            if default_key:
+                sql = text("""
+                    WITH reset AS (
+                        UPDATE public.shaken_sti_sp_conf
+                        SET default_key = NULL
+                        WHERE default_key = TRUE AND id != :id
+                    )
+                    UPDATE public.shaken_sti_sp_conf
+                    SET priv_key = COALESCE(:priv_key, priv_key),
+                        passphrase = COALESCE(:passphrase, passphrase),
+                        x5u = COALESCE(:x5u, x5u),
+                        default_key = TRUE
+                    WHERE id = :id
+                    RETURNING id;
+                """)
             else:
-                self.set_response(resp, responses.ObjectNotFoundErrorResponse(data='Config not found'))
+                sql = text("""
+                    UPDATE public.shaken_sti_sp_conf
+                    SET priv_key = COALESCE(:priv_key, priv_key),
+                        passphrase = COALESCE(:passphrase, passphrase),
+                        x5u = COALESCE(:x5u, x5u)
+                    WHERE id = :id
+                    RETURNING id;
+                """)
+
+            result = session.execute(sql, {
+                "id": object_id,
+                "priv_key": req.data.get("priv_key"),
+                "passphrase": req.data.get("passphrase"),
+                "x5u": req.data.get("x5u"),
+            })
+            session.commit()
+
+            updated_id = result.scalar()
+            if updated_id:
+                obj_data = self.get_object_data(resp, self.model_class, self.scheme_class_get, id=updated_id)
+                self.set_response(resp, responses.SuccessResponseObjectInfo(data=obj_data))
+                return True
+            else:
+                self.set_response(resp, responses.ObjectNotFoundErrorResponse())
                 return False
 
         except Exception as e:
-            log.error(f"Error during processing: {e}")
-            self.set_response(resp, responses.OperationErrorResponse(data=str(e)))
+            session.rollback()
+            log.error('Error during processing: {}'.format(str(e)))
+            self.set_response(resp, OperationErrorResponse(e))
+            return False
+
 
 class ShakenStiSpConfList(DnlList):
     scheme_class = ShakenStiSpConfScheme
